@@ -10,3 +10,6 @@ s1.chmod(0o0600)
 
 s2 = (test_folder / '../secrets/secrets-2.yaml').resolve()
 s2.chmod(0o0600)
+
+se = (test_folder / 'secrets-empty.yaml').resolve()
+se.chmod(0o0600)
