@@ -171,6 +171,28 @@ class TestSimple(unittest.TestCase):
         tv = self.auth.get_list('test-get-list-default-and-user')
         assert tv == ['user']
 
+    def test_key_only_in_user_config(self):
+        # FIXME the issue only surfaces if the value is None which is bad
+        tv_nn = self.auth.get('test-key-only-in-user-config-not-null')
+        assert tv_nn == 'hello'
+        # we need to warn on this ?? I'm pretty sure that I have made
+        # use of the ability to do this at some point in time to issue
+        # a patch fix or something like that, might be worth keeping for
+        # that reason?
+        try:
+            tv = self.auth.get('test-key-only-in-user-config')
+            # FIXME not sure if correct behavior, pretty sure
+            # we don't want this to fall through here but
+            # instead want it to be an error because it is
+            # something can only happen during development
+            # since it requires the code to know about an
+            # auth variable that the auth config does not contain
+            # FIXME we may have to do this in the linting pass
+            assert tv == None
+            assert False, 'should not get here? see comments'
+        except KeyError as e:
+            pass
+
 
 class TestMakeUserConfig(unittest.TestCase):
     def setUp(self):
@@ -203,6 +225,9 @@ class TestMakeUserConfig(unittest.TestCase):
     def test_serialize_yaml(self):
         self._roundtrip('yaml')
 
+    def test_serialize_sxpr(self):
+        self._roundtrip('sxpr')
+
 
 class TestWithStores(unittest.TestCase):
     def setUp(self):
@@ -231,6 +256,41 @@ class TestPathInConfig(unittest.TestCase):
         assert test == tv
 
 
+class TestConfigPathNoKeyFilePath(unittest.TestCase):
+    def setUp(self):
+        sc = test_folder / 'auth-get-path.yaml'
+        self.auth = oa.AuthConfig(sc)
+
+    def test_get_file_path_from_config_path(self):
+        # the case where a default value is a valid path in a secrets
+        # files could be added to linting, but cannot be default
+        # behavior due to ambiguity
+        try:
+            test = self.auth.get_path('some-path-var')
+            assert False, 'should have failed'
+        except oa.exceptions.SomethingWrongWithVariableInConfig as e:
+            pass
+
+    def test_config_path_ok(self):
+        tv = test_folder / 'somewhere-else' / 'some-other-file.ext'
+        test = self.auth.get_path('spv-1')
+        assert test == tv
+
+    def test_config_path_missing(self):
+        try:
+            test = self.auth.get_path('spv-2')
+            assert False, 'should have failed'
+        except oa.exceptions.SecretError as e:
+            pass
+
+    def test_config_path_beyond(self):
+        try:
+            test = self.auth.get_path('spv-3')
+            assert False, 'should have failed'
+        except oa.exceptions.SecretError as e:
+            pass
+
+
 class TestBadPaths(unittest.TestCase):
     def setUp(self):
         sc = test_folder / 'auth-config-bad-paths.yaml'
@@ -242,3 +302,23 @@ class TestBadPaths(unittest.TestCase):
             assert False, 'should have failed'
         except oa.exceptions.SomethingWrongWithVariableInConfig as e:
             print(e)
+
+
+class TestEmptySecrets(unittest.TestCase):
+    def setUp(self):
+        sc = test_folder / 'auth-config-empty-secrets.yaml'
+        self.auth = oa.AuthConfig(sc)
+
+    def test_empty_path(self):
+        try:
+            test = self.auth.get_path('missing')
+            assert False, 'should have failed'
+        except oa.exceptions.EmptyConfigError as e:
+            print(e)
+
+    def test_empty_value(self):
+        try:
+            test = self.auth.get('missing')
+            assert False, 'should have failed'
+        except oa.exceptions.EmptyConfigError as e:
+            print(e)
